MacroRankBasedEvaluator
=======================

.. currentmodule:: pykeen.evaluation

.. autoclass:: MacroRankBasedEvaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MacroRankBasedEvaluator.clear
      ~MacroRankBasedEvaluator.finalize
      ~MacroRankBasedEvaluator.process_scores_

   .. rubric:: Methods Documentation

   .. automethod:: clear
   .. automethod:: finalize
   .. automethod:: process_scores_
